@@ -45,6 +45,10 @@ class ReturnAccessTokenSerializer(serializers.Serializer):
     access_token = serializers.CharField(label='Jwt token for authentication')
 
 
+class ReturnJWTTokensSerializer(ReturnAccessTokenSerializer):
+    refresh_token = serializers.CharField(label='Refresh token for access token')
+
+
 class ReturnRegisterSerializer(ReturnAccessTokenSerializer):
     refresh_token = serializers.CharField(label='Jwt token for refresh access token')
 
