@@ -51,7 +51,7 @@ class TwilioBackend(BasePhoneBackend):
 
     def send(self, to_phone, message, from_phone=None):
         if from_phone is None:
-            from_phone = self.configs['DEFAULT_FROM_NUMBER']
+            from_phone = self.configs['TWILIO_FROM_NUMBER']
         try:
             self.client.messages.create(to=f"+{to_phone}", from_=from_phone, body=message)
         except TwilioRestException:
