@@ -4,6 +4,7 @@ from rest_framework.routers import DefaultRouter
 from drf_auth_service.authentication.views import LoginViewSet, EBSTokenRefreshView
 from drf_auth_service.settings import settings
 from drf_auth_service.socials.views import social_login
+from drf_auth_service.users.views import UserViewSet
 
 router = DefaultRouter(trailing_slash=False)
 router.register(r'services', settings.VIEWS.SERVICE_VIEWS, basename='service')
@@ -13,5 +14,5 @@ router.register(r'authentication', settings.VIEWS.AUTHENTICATION_VIEWS, basename
 urlpatterns = router.urls + [
     path('authentication/login', LoginViewSet.as_view(), name='token_obtain_pair'),
     path('authentication/oauth', social_login, name='social_login'),
-    path('authentication/refresh', EBSTokenRefreshView.as_view(), name='token_refresh'),
+    path('authentication/refresh', EBSTokenRefreshView.as_view(), name='token_refresh')
 ]
